<?php 
/**
* Plugin Main Class
*/
class WCP_Coming_Soon
{
	
	function __construct()
	{
		// Admin related
		add_action( 'add_meta_boxes', array($this, 'product_meta_box') );
		add_action( 'admin_enqueue_scripts', array($this, 'inserting_admin_scripts') );
		add_action( 'save_post', array($this, 'wcp_saving_meta') );
		add_filter( 'manage_product_posts_columns', array($this, 'product_column_head'));
		add_action( 'manage_product_posts_custom_column', array($this, 'product_column_content'), 10, 2);
		add_action( 'admin_menu', array( $this, 'wcp_admin_settings' ) );
		add_action( 'wp_ajax_csp_save_admin_settings', array( $this, 'csp_save_admin_settings' ) );
		add_action( 'send_emails_to_subscribers', array($this, 'send_emails'), 10, 1);
		add_shortcode( 'wccs', array($this, 'render_sc_clock') );

		// Frontend
		add_action( 'wp_enqueue_scripts', array($this, 'inserting_front_scripts') );
		add_action( 'wp_ajax_wcp_save_email', array($this, 'saving_email_address') );
		add_action( 'wp_ajax_nopriv_wcp_save_email', array($this, 'saving_email_address') );

		$settings = get_option( 'csp_admin_settings' );
		$big_clock_hook = (isset($settings['render_clock_single_action']) && $settings['render_clock_single_action'] != '') ? $settings['render_clock_single_action'] : 'woocommerce_product_meta_start' ;
		$email_form_hook = (isset($settings['render_form_single_action']) && $settings['render_form_single_action'] != '') ? $settings['render_form_single_action'] : 'woocommerce_product_meta_start' ;
		$small_clock_hook = (isset($settings['render_clock_loop_action']) && $settings['render_clock_loop_action'] != '') ? $settings['render_clock_loop_action'] : 'woocommerce_after_shop_loop_item' ;

		// Woo Hooks
		add_action( $big_clock_hook, array($this, 'render_big_clock') );
		add_action( $email_form_hook, array($this, 'render_email_form') );
		add_action( $small_clock_hook, array($this, 'render_small_clock'), 10, 1);
		add_filter( 'woocommerce_short_description', array( $this, 'short_desc' ) );

		add_filter( 'woocommerce_is_purchasable', array($this, 'remove_add_to_cart'), 50, 2 );
		add_filter( 'woocommerce_variation_is_purchasable', array($this, 'remove_add_to_cart_variation'), 50, 2 );
		add_filter( 'woocommerce_get_price_html', array($this, 'remove_price'), 50, 2 );
		add_filter( 'woocommerce_product_tabs', array($this, 'remove_tabs'), 50 );
		add_action( 'plugins_loaded', array($this, 'wcp_load_plugin_textdomain' ) );

		add_filter( 'woocommerce_default_catalog_orderby_options', array($this, 'add_new_orderby_filter') );
		add_filter( 'woocommerce_catalog_orderby',  array($this, 'add_new_orderby_filter') );
		add_filter( 'woocommerce_get_catalog_ordering_args', array($this, 'cw_add_postmeta_ordering_args'), 10, 3 );

		add_action( 'woocommerce_variation_options_pricing', array($this, 'wccs_add_custom_variation_fields'), 10, 3 );
		add_action( 'woocommerce_save_product_variation', array($this, 'wccs_save_custom_variation_fields'), 10, 2 );

		add_filter( 'woocommerce_available_variation', array($this, 'add_time_field_variation_data') );

		// Admin Sorting
		add_filter( 'restrict_manage_posts', array($this, 'filter_products_admin'), 10 );
		add_filter( 'parse_query', array($this, 'filter_by_release_date'), 10, 1 );
		
	}

	function add_time_field_variation_data( $variations ) {
		if (isset($variations[ 'variation_id' ]) && get_post_meta( $variations[ 'variation_id' ], '_coming_soon_date', true ) != '') {
			$wccs_date = get_post_meta( $variations[ 'variation_id' ], '_coming_soon_date', true );
			$date = strtotime($wccs_date) - time();
	   		$variations['wccs_time'] = $date;
		}

	   return $variations;
	}

	function add_new_orderby_filter( $sortby ) {
		$settings = get_option( 'csp_admin_settings' );
		if (!isset($settings['sorting']) || $settings['sorting'] != 'on') {
			$sortby['release_date_asc'] = __( 'Sort By release date (ASC)', 'wccs' );
			$sortby['release_date_desc'] = __( 'Sort By release date (DESC)', 'wccs' );
		}
	  	return $sortby;
	}

	function wccs_add_custom_variation_fields( $loop, $variation_data, $variation ) {

		echo '<div class="options_group form-row form-row-full coming-soon-variation">';

	 	// Text Field
		woocommerce_wp_text_input(
			array(
				'id'          => '_coming_soon_date[' . $variation->ID . ']',
				'label'       => __( 'Release Date (WOO Coming Soon)', 'wccs' ),
				'desc_tip'    => true,
				'class'    => 'wccs-variation',
				'description' => __( "Leave blank to disable coming soon mode", "wccs" ),
				'value' => get_post_meta( $variation->ID, '_coming_soon_date', true )
			)
	 	);

		echo '</div>';

	}

	function wccs_save_custom_variation_fields($post_id){
	 	if (isset($_POST['_coming_soon_date'][ $post_id ])) {
			update_post_meta( $post_id, '_coming_soon_date', esc_attr( $_POST['_coming_soon_date'][ $post_id ] ) );
	 	}
	}

	function cw_add_postmeta_ordering_args( $args_sort_cw  ,$orderby, $order) {
	 
	 $cw_orderby_value = isset( $_GET['orderby'] ) ? wc_clean( $_GET['orderby'] ) :
	    apply_filters( 'woocommerce_default_catalog_orderby', get_option( 'woocommerce_default_catalog_orderby' ) );
	 	switch( $cw_orderby_value ) {
		   	case 'release_date_asc':
		    	$args_sort_cw['orderby'] = 'meta_value_num';
				$args_sort_cw['order'] = 'ASC';
		    	$args_sort_cw['meta_key'] = 'wcp_release_time';
		    	
		    break;
		    case 'release_date_desc':
				$args_sort_cw['orderby'] = 'meta_value_num';
		     	$args_sort_cw['order'] = 'DESC';
				$args_sort_cw['meta_key'] = 'wcp_release_time';
		    break;
		}
		return $args_sort_cw;
	}

	function wcp_load_plugin_textdomain(){
	    load_plugin_textdomain( 'wccs', FALSE, basename( WCCS_PATH ) . '/languages/' );
	}

	function remove_tabs($tabs){
		$product = wc_get_product();
		$product_id = $product->get_id();
		if ($this->is_countdown_valid($product_id)) {
			$settings = get_option( 'csp_admin_settings' );
			if (isset($settings['tabs']) && $settings['tabs'] == 'on') {
				$tabs = array();
			}
		}
		return $tabs;
	}

	function remove_add_to_cart_variation($is_purchasable, $variation) {
		$variation_id = $variation->get_id();
		$csmode = get_post_meta( $variation_id, '_coming_soon_date', true );
		if ($csmode != '') {
			$date = strtotime($csmode) - time();
			if (intval($date) > 0) {
				return false;
			}
		}
		return $is_purchasable;
	}

	function remove_add_to_cart($is_purchasable, $product) {
	    $product_id = $product->get_id();
		return ($this->is_countdown_valid($product_id)) ? false : $is_purchasable;
	}

	function remove_price($price, $instance){
		$settings = get_option( 'csp_admin_settings' );
		if (isset($settings['price']) && $settings['price'] == 'on') {
			$product = wc_get_product();
			if (is_object($product) && $this->is_countdown_valid($product->get_id())) {
				$price = '';
			}
		}
		return $price;
	}

	function product_meta_box($slug){
		add_meta_box( 'wccs-box', __( 'Coming Soon Mode', 'wccs' ), array($this, 'wcp_render_options'), 'product', 'side' );
		add_meta_box( 'wccs-emails', __( 'Coming Soon Subscribers', 'wccs' ), array($this, 'wcp_render_emails_list'), 'product', 'side' );
	}

	function wcp_render_options($product){
		include WCCS_PATH.'/inc/mb-form.php';
	}

	function wcp_render_emails_list($product){
		include WCCS_PATH.'/inc/mb-subscribers.php';
    }

	function inserting_admin_scripts($slug){
		if ($slug == 'post.php') {
			wp_enqueue_style( 'wcp-datepicker-css', plugin_dir_url( __FILE__ ) . 'css/jquery-ui-timepicker-addon.css');
			wp_enqueue_script( 'wcp-datepicker-js', plugin_dir_url( __FILE__ ) . 'js/jquery-ui-timepicker-addon.js', array('jquery', 'jquery-ui-datepicker'));
			wp_enqueue_script( 'wcp-csp', plugin_dir_url( __FILE__ ) . 'js/admin.js', array('jquery'));
		}

		if ($slug == 'woocommerce_page_cs_product') {
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'wp-color-picker' );
			$msgs = array( 'title' => __( 'Please Wait!', 'wccs' ), 'message' => __( 'Saving Settings...', 'wccs' ));
			wp_enqueue_script( 'wcp-sweetalerts', plugin_dir_url( __FILE__ ) . 'js/sweetalert.min.js', array('jquery'));	
			wp_enqueue_script( 'wcp-admin-page', plugin_dir_url( __FILE__ ) . 'js/admin-page.js', array('jquery'));	
			wp_localize_script( 'wcp-admin-page', 'wccs_vars', $msgs );
		}

	}

	function wcp_saving_meta($product_id){        
		if (isset($_POST['wcp_meta'])) {
			$ex_meta = get_post_meta( $product_id, 'wcp_meta', true );

			$saved_date = (isset($ex_meta['time'])) ? $ex_meta['time'] : '' ;

			update_post_meta( $product_id, 'wcp_meta', $_POST['wcp_meta'] );

			if (isset($ex_meta['time']) && $ex_meta['time'] != '' && isset($_POST['wcp_meta']['enable']) && $_POST['wcp_meta']['enable'] == 'on') {
				update_post_meta( $product_id, 'wcp_release_time', strtotime($ex_meta['time']) );
			} else {
				delete_post_meta( $product_id, 'wcp_release_time' );
			}

			if (isset($_POST['wcp_meta']['enable']) && $_POST['wcp_meta']['enable'] == 'on' && $_POST['wcp_meta']['time'] != $saved_date) {
				wp_clear_scheduled_hook( 'send_emails_to_subscribers', array($product_id) );
				wp_schedule_single_event( strtotime($_POST['wcp_meta']['time']), 'send_emails_to_subscribers', array($product_id) );
			}
			if (!isset($_POST['wcp_meta']['enable'])) {
				wp_clear_scheduled_hook( 'send_emails_to_subscribers', array($product_id) );
			}
		}

	}

	function inserting_front_scripts(){
		if (is_product()) {
			wp_enqueue_style( 'wccs-flipclock', plugin_dir_url( __FILE__ ) . 'css/flipclock.css');
			wp_enqueue_script( 'wcp-sweetalerts', plugin_dir_url( __FILE__ ) . 'js/sweetalert.min.js', array('jquery'));
			wp_enqueue_script( 'wccs-flipclock', plugin_dir_url( __FILE__ ) . 'js/flipclock.min.js', array('jquery'));
			wp_enqueue_script( 'wccs-custom-script', plugin_dir_url( __FILE__ ) . 'js/script.js', array('jquery'));

			$texts = array(
				'days' => __( 'Days', 'wccs' ),
				'hours' => __( 'Hours', 'wccs' ),
				'minutes' => __( 'Minutes', 'wccs' ),
				'seconds' => __( 'Seconds', 'wccs' ),
				'years' => __( 'Years', 'wccs' ),
				'months' => __( 'Months', 'wccs' ),
			);

			wp_localize_script( 'wccs-flipclock', 'wccs_clock', $texts );

			$msgs = array(
				'title' => __( 'Please Wait!', 'wccs' ),
				'message' => __( 'Saving email address...', 'wccs' ),
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'path' => plugin_dir_url( __FILE__ ),
			);
			wp_localize_script( 'wccs-custom-script', 'wcp', $msgs);			
		}
		if(is_shop() || is_product_category() || is_product()){
			wp_enqueue_style( 'wccs-flipclock-mini', plugin_dir_url( __FILE__ ) . 'css/flipclockmini.css');
			wp_enqueue_script( 'wccs-flipclock', plugin_dir_url( __FILE__ ) . 'js/flipclock.min.js', array('jquery'));
			$texts = array(
				'days' => __( 'Days', 'wccs' ),
				'hours' => __( 'Hours', 'wccs' ),
				'minutes' => __( 'Minutes', 'wccs' ),
				'seconds' => __( 'Seconds', 'wccs' ),
				'years' => __( 'Years', 'wccs' ),
				'months' => __( 'Months', 'wccs' ),
			);

			wp_localize_script( 'wccs-flipclock', 'wccs_clock', $texts );			
			wp_enqueue_script( 'wccs-flipclock-mini', plugin_dir_url( __FILE__ ) . 'js/scriptmini.js', array('jquery'));
		}
	}

	function render_big_clock(){
		$product = wc_get_product();
		$product_id = $product->get_id();
		if ("variable" == $product->get_type()) {
			$in_theme = get_stylesheet_directory().'/wccs/variable-clock.php';
			if (file_exists($in_theme)) {
				include $in_theme;
			} else {
				include WCCS_PATH.'/inc/variable-clock.php';
			}
		} else {
			if ($this->is_countdown_valid($product_id)) {
				$in_theme = get_stylesheet_directory().'/wccs/big-clock.php';
				if (file_exists($in_theme)) {
					include $in_theme;
				} else {
					include WCCS_PATH.'/inc/big-clock.php';
				}
			}
		}
	}

	function render_sc_clock($attrs){
		ob_start();
		wp_enqueue_style( 'wccs-flipclock', plugin_dir_url( __FILE__ ) . 'css/flipclock.css');
		wp_enqueue_script( 'wcp-sweetalerts', plugin_dir_url( __FILE__ ) . 'js/sweetalert.min.js', array('jquery'));
		wp_enqueue_script( 'wccs-flipclock', plugin_dir_url( __FILE__ ) . 'js/flipclock.min.js', array('jquery'));
		wp_enqueue_script( 'wccs-custom-script', plugin_dir_url( __FILE__ ) . 'js/script.js', array('jquery'));

		$texts = array(
			'days' => __( 'Days', 'wccs' ),
			'hours' => __( 'Hours', 'wccs' ),
			'minutes' => __( 'Minutes', 'wccs' ),
			'seconds' => __( 'Seconds', 'wccs' ),
			'years' => __( 'Years', 'wccs' ),
			'months' => __( 'Months', 'wccs' ),
		);

		wp_localize_script( 'wccs-flipclock', 'wccs_clock', $texts );

		$msgs = array(
			'title' => __( 'Please Wait!', 'wccs' ),
			'message' => __( 'Saving email address...', 'wccs' ),
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
			'path' => plugin_dir_url( __FILE__ ),
		);
		wp_localize_script( 'wccs-custom-script', 'wcp', $msgs);		
		if (isset($attrs['id']) && $attrs['id'] != '') {
			$product_id = $attrs['id'];
		} else {
			$product = wc_get_product();
			$product_id = $product->get_id();
		}
		if ($this->is_countdown_valid($product_id)) {
			$in_theme = get_stylesheet_directory().'/wccs/big-clock.php';
			if (file_exists($in_theme)) {
				include $in_theme;
			} else {
				include WCCS_PATH.'/inc/big-clock.php';
			}
		}

		return ob_get_clean();
	}

	function is_countdown_valid($product_id){
		$return = false;
		$csdata = get_post_meta( $product_id, 'wcp_meta', true );
		if (isset($csdata['enable']) && $csdata['enable'] == 'on' && isset($csdata['time']) && $csdata['time'] != '') {
			$date = strtotime($csdata['time']) - time();
			if (intval($date) > 0) {
				$return = true;
			}
		}
		return $return;
	}

	function render_email_form(){
		$product = wc_get_product();
		if ("variable" != $product->get_type()) {
			$product_id = $product->get_id();
			$settings = get_option( 'csp_admin_settings' );
			$csdata = get_post_meta( $product_id, 'wcp_meta', true );
			$style = isset($settings['formstyle']) ? esc_attr( $settings['formstyle'] ) : 1;
			if ($this->is_countdown_valid($product_id) && isset($csdata['email'])) {
				$in_theme = get_stylesheet_directory().'/wccs/style2.php';
				if (file_exists($in_theme)) {
					include $in_theme;
				} else {
					include WCCS_PATH.'/inc/form/style'.$style.'.php';
				}
			}
		}
	}

	function saving_email_address(){
		if (isset($_REQUEST['email']) && isset($_REQUEST['id'])) {
			$email_address = $_REQUEST['email'];
			$product_id = $_REQUEST['id'];
			$product_url = get_permalink( $product_id );
			$product_name = get_the_title( $product_id );
			$product_sku = get_post_meta( $product_id, '_sku', true );
			$emails_list = get_post_meta( $product_id, 'wcp_emails_list', true );
			if (is_array($emails_list) && !in_array($email_address, $emails_list)) {
				$emails_list[] = $email_address;
			} else {
				$emails_list = array($email_address);
			}
			$resp = array('status' => 'info', 'title' => __( 'Already Exists', 'wccs' ), 'message' => __( 'Your email address is already saved', 'wccs' ));
			if (update_post_meta( $product_id,'wcp_emails_list', $emails_list )) {
			    $resp['status'] = 'success';
			    $resp['title'] = __( 'Success!', 'wccs' );
			    $resp['message'] = __( 'Your email address is saved successfully.', 'wccs' );
			    $settings = get_option( 'csp_admin_settings' );
			    if (isset($settings['admin_email']) && $settings['admin_email'] != '') {
			    	$message = (isset($settings['admin_message'])) ? $settings['admin_message'] : 'You got a new subscriber.' ;
			    	$message = str_replace("%USER_EMAIL%", $email_address, $message);
			    	$message = str_replace("%PRODUCT_ID%", $product_id, $message);
			    	$message = str_replace("%PRODUCT_URL%", $product_url, $message);
			    	$message = str_replace("%PRODUCT_NAME%", $product_name, $message);
			    	$message = str_replace("%PRODUCT_SKU%", $product_sku, $message);

			    	$to = $settings['admin_email'];
			    	$subject = $settings['admin_subject'];
			    	$headers = array('Content-Type: text/html; charset=UTF-8');
			    	 
			    	wp_mail( $to, $subject, $message, $headers );			    	
			    }
			    $settings = get_option( 'csp_admin_settings' );
			    $csdata = get_post_meta( $product_id, 'wcp_meta', true );
			    if (isset($settings['mc_api_key']) && $settings['mc_api_key'] != '' && isset($csdata['mc_list_id']) && $csdata['mc_list_id'] != '') {
			    	$MailChimp = new WCCS_MailChimp(trim($settings['mc_api_key']));
			    	$MailChimp->post("lists/{$csdata['mc_list_id']}/members", array(
    					'email_address' => $email_address,
    					'status'        => 'subscribed',
    				));
			    }			    
			}
			echo json_encode($resp);
		}
		die(0);
	}

	function product_column_head($defaults){
		$defaults['wcp_email_count'] = '<span title="'.__( 'Coming Soon Subscribers Count', 'wccs' ).'" class="dashicons dashicons-clock"></span>';
		return $defaults;		
	}

	function product_column_content($column_name, $product_ID){
		if ($column_name == 'wcp_email_count') {		
			$csdata = get_post_meta( $product_ID, 'wcp_meta', true );
	        if (isset($csdata['enable']) && $csdata['enable'] == 'on') {
	        	$emails_list = get_post_meta( $product_ID, 'wcp_emails_list', true );
	            if (is_array($emails_list)) {
	            	echo count($emails_list);
	            }
	            else {
	            	echo '0';
	            }
	        }
	        else {
	        	echo '<span title="'.__( 'Coming Soon Mode Disabled', 'wccs' ).'" class="dashicons dashicons-warning"></span>';
	        }
	    }
	}

	function send_emails($prod_id){
		$ex_data = get_post_meta( $prod_id, 'wcp_meta', true );
		if (isset($ex_data['enable']) && $ex_data['enable'] == 'on') {
			$emails_list = get_post_meta( $prod_id, 'wcp_emails_list', true );
			$title = apply_filters( 'wccs_email_title', bloginfo('name') );
			$from = apply_filters( 'wccs_email_from', $ex_data['emailfrom'] );
			$subject = apply_filters( 'wccs_email_subject', $ex_data['emailsubject'] );
			$message = apply_filters( 'wccs_email_message', $ex_data['emailtext'] );
			
			
			if (is_array($emails_list)) {
				$headers = array();
	            $headers[] = "From: {$title} <{$from}>";
	    		
	    		foreach($emails_list as $emailaddress) {
	    		    $headers[] = "Bcc: $emailaddress";
	    		}
	    		
	    		$headers[] = "Content-Type: text/html";
	    		$headers[] = "MIME-Version: 1.0\r\n";
	    		
				wp_mail( $from, $subject, stripslashes($message), $headers);
			}
			$settings = array('enable' => 'off');
			update_post_meta( $prod_id, 'wcp_meta', $settings );
			delete_post_meta( $prod_id, 'wcp_release_time' );
		}
	}

	function render_small_clock(){
		$product = wc_get_product();
		$product_id = $product->get_id();
		if ($this->is_countdown_valid($product_id)) {
			$in_theme = get_stylesheet_directory().'/wccs/small-clock.php';
			if (file_exists($in_theme)) {
				include $in_theme;
			} else {
				include WCCS_PATH.'/inc/small-clock.php';
			}
		}
	}

	function wcp_admin_settings(){
		add_submenu_page( 'woocommerce', 'Coming Soon Product', 'Coming Soon Settings', 'manage_options', 'cs_product', array($this, 'render_admin_page') );
	}

	function render_admin_page(){
		include WCCS_PATH.'/inc/settings.php';
	}

	function csp_save_admin_settings(){
		if (isset($_REQUEST)) {
			$resp = array('status' => '', 'title' => '', 'message' => '');
			if (update_option( 'csp_admin_settings', $_REQUEST )) {
			    $resp['status'] = 'success';
			    $resp['title'] = __( 'Settings Saved!', 'wccs' );
			    $resp['message'] = __( 'Settings are saved in the database successfully.', 'wccs' );
			} else {
			    $resp['status'] = 'error';
			    $resp['title'] = __( 'Failed!', 'wccs' );
			    $resp['message'] = __( 'There is some error or you did not make any change.', 'wccs' );
			}
		}

		echo json_encode($resp);

		die(0);
	}

	function short_desc($default_desc){
		$product = wc_get_product();
		if ($product) {
			$product_id = $product->get_id();
			
			$wcp_admin = get_option( 'csp_admin_settings' );
			if (is_array($wcp_admin)) {
				extract($wcp_admin);
			}
			$csdata = get_post_meta( $product_id, 'wcp_meta', true );
			if (isset($csdata['enable']) && $csdata['enable'] == 'on' && isset($desc) && $desc != '') {
				return stripcslashes($desc);
			}
			else {
				return $default_desc;
			}
		}
		return $default_desc;
	}

	function render_settings_field($field){
		$settings = get_option( 'csp_admin_settings' );
		$val = (isset($settings[$field['name']])) ? $settings[$field['name']] : '';
		switch ($field['type']) {
			case 'text':
				echo '<input name="'.$field['name'].'" type="text" value="'.$val.'" class="widefat">';
				break;
			case 'checkbox':
				echo '<label><input name="'.$field['name'].'" type="checkbox" '.checked( $val, 'on', false ).'>'.__( 'Hide', 'wccs' ).'</label>';
				break;
			case 'textarea':
				echo '<textarea name="'.$field['name'].'" class="widefat">'.stripcslashes($val).'</textarea>';
				break;
			case 'color':
				echo '<input type="text" name="'.$field['name'].'" value="'.$val.'" class="colorpicker">';
				break;
			case 'select':
				echo '<select class="widefat" name="'.$field['name'].'">';
				foreach ($field['options'] as $key => $label) {
					echo '<option '.selected( $val, $key ).' value="'.$key.'">'.$label.'</option>';
				}
				echo '</select>';
				break;
			
			default:
				# code...
				break;
		}
	}

	function filter_products_admin($post_type){
	    if ('product' == $post_type) {
	        $selected = (isset($_GET['wccs_date'])) ? $_GET['wccs_date'] : '' ;
	        ?>
	            <select name="wccs_date" id="filter-by-wccs">
	                <option value=""><?php _e( 'Filter by Release Date', 'wccs' ) ?></option>
	                <option value="this_month" <?php selected( $selected, 'this_month'); ?>><?php _e( 'Releasing this Month', 'wccs' ) ?></option>
	                <option value="next_month" <?php selected( $selected, 'next_month'); ?>><?php _e( 'Releasing next Month', 'wccs' ) ?></option>
	                <option value="three_months" <?php selected( $selected, 'three_months'); ?>><?php _e( 'Releasing within 3 Months', 'wccs' ) ?></option>
	            </select>
	        <?php
	    }
	}

	function filter_by_release_date($query){

	    //modify the query only if it admin and main query.
	    if( !(is_admin() AND $query->is_main_query()) ){ 
	      return $query;
	    }

	    //we want to modify the query for the targeted custom post and filter option
	    if( !('product' === $query->query['post_type']) ){
	      return $query;
	    }

	    if (isset($_GET['wccs_date']) && $_GET['wccs_date'] != '') {
	        $exp_period = sanitize_text_field( $_GET['wccs_date'] );
	        if ($exp_period == 'this_month') {
	            $today = date('Y-m-d');
	            $last_day_this_month  = date('Y-m-t');
	            $query->query_vars['meta_query'][] = array(
	                'key'     => 'wcp_release_time',
	                'value'   => array( strtotime($today), strtotime($last_day_this_month) ),
	                'compare' => 'BETWEEN',
	            );
	        }
	        if ($exp_period == 'next_month') {
	            $next_month_start = date("Y-m-01", strtotime( '+1 month' ));
	            $next_month_end = date("Y-m-t", strtotime( '+1 month' ));
	            $query->query_vars['meta_query'][] = array(
	                'key'     => 'wcp_release_time',
	                'value'   => array( strtotime($next_month_start), strtotime($next_month_end) ),
	                'compare' => 'BETWEEN',
	            );
	        }
	        if ($exp_period == 'three_months') {
	            $today = date('Y-m-d');
	            $third_month_end = date("Y-m-t", strtotime( '+3 month' ));
	            $query->query_vars['meta_query'][] = array(
	                'key'     => 'wcp_release_time',
	                'value'   => array( strtotime($today), strtotime($third_month_end) ),
	                'compare' => 'BETWEEN',
	            );
	        }
	    }

	    return $query;
	}

}

?>